asr.test.mocks.gpaw.response.g0w0
=================================

.. automodule:: asr.test.mocks.gpaw.response.g0w0

   
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: G0W0
      :members:
   
   

   
   
   